/*
Program : TestHelp.prg
Purpose : Test HTML help file use with FWH
App     :
Author  : James Bott, jbott@compuserve.com
Date    : 01/18/05 10:04:40
Notice  : Copyright Intellitech 2005. All rights reserved.
Language: FWH 2.4, July 2003 build/Harbour 43 flex
Notes   :


FWH built-in help functions for winhelp (.hlp)

helpIndex
helpPopup
helpSearch
helpSetPos
helpTopic
getHelpTopic
helpSetTopic
getHelpFile
setHelpFile

Here we implement replacement functions for use with .CHM help file format:

helpIndex()
helpTopic()
helpPopup()

These existing functions can still be used with CHM files:

setHelpFile()
getHelpFile()
helpSetTopic()  // we have added setHelpTopic()
getHelpTopic()

You cannot use:

helpSearch()
helpSetPos()


*/


#include "fivewin.ch"

#define APP_HELPFILE  "myhelp.chm"

//----------------------------------------------------------------------------//

function main()
   local oWnd,oBar

  setHelpFile( APP_HELPFILE )

  define window oWnd
  oWnd:nHelpID:="intro.htm"
  define buttonbar oBar of oWnd

  // Sample call to specific topic. Note that topic must be a HTML page.
  define button of oBar action helpTopic("orders.htm") tooltip 'helpTopic("orders.chm")'

  //--- These are .HLP format functions that are not available with HTML help
  //define button of oBar action helpIndex() tooltip "helpIndex()"
  //define button of oBar action helpSearch() tooltip "helpSearch()"
  //define button of oBar action helpPopup() tooltip "helpPopup()"

  // Create a dialog for testing new default help topic
  define button of oBar action testDialog() group tooltip "Open dialog"

  //define button of oBar action msgInfo( oWnd:nHelpID )

  set message to "Press F1 for help" of oWnd

  activate window oWnd

return nil

//----------------------------------------------------------------------------//
/* Notes: You could change the current help topic for each window/dialog, but this also
requires saving and restoring the previous one. It seems to be easier to assign the topic to
nHelpID instead. Then the current help topic is not affected.
*/

function testDialog()
   local oDlg,oGet,oBtn,cName:="Frank         "
   //local cHelpTopic:= getHelpTopic() // remember current help topic
   //setHelpTopic("orders.htm")  // set topic for this dialog

   define dialog oDlg
   oDlg:lHelpIcon:=.f. // Turn off help icon on caption bar
   oDlg:nHelpID:="ORDERS.HTM"

   @ 1,1 get oGet var cName of oDlg
   //oGet:nHelpid:= "orders.htm"

   @ 2,1 say "Press F1 for help" of oDlg
   @ 3,6 button oBtn prompt "Help" of oDlg action helpTopic("orders.htm")
   activate dialog oDlg

   //setHelpTopic( cHelpTopic )  // restore previous help topic

return nil


//---------------------------------------------------------------------------//

/*
Purpose : Replacement FW(H) functions to allow use of .CHM (compiled HTML) help files.
Author  : James Bott, jbott@compuserve.com
Date    : 1/20/05
Language: FWH 2.4, July 2003 build/Harbour 43 Flex
Notes   : Some of the standard FWH help functions have been replaced here.
          Requires HH.EXE which is already on most PC's. Older ones may require
          an upgrade (Free, available at www.microsoft.com)

          Also requires a modified control.prg file from Fivewin, otherwise
          help files are loaded twice. In the handleEvent() method commnent out
          these two lines:

            //case nMsg == WM_HELP
                 //return ::HelpTopic()

*/

//----------------------------------------------------------------------------//

function helpIndex()
   if !empty(getHelpFile())
      if file(getHelpFile())
         shellExecute( 0, "open", gethelpFile(), 0, 0, 1)
      else
         msgAlert( getHelpFile()+" not found.")
      endif
   else
      msgAlert("No help file defined.")
   endif
return nil

//----------------------------------------------------------------------------//

function helpTopic( cTopic ) // cTopic is filename, e.g. "intro.htm"
   local cHelpFile:= getHelpFile()
   default cTopic:= getHelpTopic()
   if !empty( cTopic )
      if !empty( cHelpFile )
         if file( cHelpFile )
            ShellExecute( 0, "open","HH.EXE", cHelpFile+"::/"+alltrim(cTopic), 0, 1 )
         else
            msgAlert( cHelpFile+" not found.")
         endif
      else
         msgAlert("No help file defined.")
      endif
   else
      helpIndex()
   endif
return nil

//----------------------------------------------------------------------------//

// New function just to provide consistant function naming.
// FWH has getHelpTopic() and helpSetTopic()
function setHelpTopic( cTopic )
return helpSetTopic( cTopic )

//----------------------------------------------------------------------------//

// This is a crude replacement. I don't think you can make an popup display
// using HH.EXE, so we just call helpTopic() instead.
function helpPopup( nHelpID )
return helpTopic( nHelpID )

//----------------------------------------------------------------------------//

//function winHelp()
//return msgINfo("winhelp()")

//function htmlHelp()
//return msgInfo("HtmlHelp()")

// eof

